# Changelog

## 1.1.0 (2026-01-14)

Full Changelog: [v1.0.5...v1.1.0](https://github.com/brapi-dev/brapi-python/compare/v1.0.5...v1.1.0)

### Features

* **client:** add support for binary request streaming ([f7eb87e](https://github.com/brapi-dev/brapi-python/commit/f7eb87e9fc953d88d4089f62da193dac2348f940))


### Chores

* **internal:** codegen related update ([320cbf8](https://github.com/brapi-dev/brapi-python/commit/320cbf88b64040419879dd30e0afd4e349ddbd16))

## 1.0.5 (2025-12-19)

Full Changelog: [v1.0.4...v1.0.5](https://github.com/brapi-dev/brapi-python/compare/v1.0.4...v1.0.5)

### Bug Fixes

* use async_to_httpx_files in patch method ([a061229](https://github.com/brapi-dev/brapi-python/commit/a0612291f12c3dbc71faab50d3beb93848801db3))


### Chores

* **internal:** add `--fix` argument to lint script ([76c6f31](https://github.com/brapi-dev/brapi-python/commit/76c6f31884a3fc3588c955002aba49679fd42e9b))
* **internal:** add missing files argument to base client ([cababd6](https://github.com/brapi-dev/brapi-python/commit/cababd656bcc34c68419a4d00812965f92e0fa5c))
* speedup initial import ([7261e02](https://github.com/brapi-dev/brapi-python/commit/7261e025f7cf5448c964892296d7c54999926cdd))

## 1.0.4 (2025-12-09)

Full Changelog: [v1.0.3...v1.0.4](https://github.com/brapi-dev/brapi-python/compare/v1.0.3...v1.0.4)

### Bug Fixes

* ensure streams are always closed ([d1f3a3e](https://github.com/brapi-dev/brapi-python/commit/d1f3a3e1d98fb1ed84e31a58a1df5332446cd793))
* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([d1f1fcc](https://github.com/brapi-dev/brapi-python/commit/d1f1fcc15a0457f8c03ed22ed76730bee6b56fc1))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([c03a35a](https://github.com/brapi-dev/brapi-python/commit/c03a35aa19cb32632f2929ebe8e44c171445e5fd))
* **docs:** use environment variables for authentication in code snippets ([f80ab62](https://github.com/brapi-dev/brapi-python/commit/f80ab628737e2f32db10fc63b47ad0339733c57f))
* update lockfile ([972cee4](https://github.com/brapi-dev/brapi-python/commit/972cee46353bc8dd7a096f975ae233e508bcf6ec))

## 1.0.3 (2025-11-22)

Full Changelog: [v1.0.2...v1.0.3](https://github.com/brapi-dev/brapi-python/compare/v1.0.2...v1.0.3)

### Chores

* add Python 3.14 classifier and testing ([bb6876e](https://github.com/brapi-dev/brapi-python/commit/bb6876e969d28e9458d89cc54c134c43261397e6))

## 1.0.2 (2025-11-12)

Full Changelog: [v1.0.1...v1.0.2](https://github.com/brapi-dev/brapi-python/compare/v1.0.1...v1.0.2)

### Bug Fixes

* **client:** close streams without requiring full consumption ([a23e5a4](https://github.com/brapi-dev/brapi-python/commit/a23e5a4c2d30869c11ab6e09f3eea4ee847c68c4))
* compat with Python 3.14 ([7d86ba1](https://github.com/brapi-dev/brapi-python/commit/7d86ba177c65bde5e0e84c2b7dea7e0f1667cce5))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([220d879](https://github.com/brapi-dev/brapi-python/commit/220d879c5e6ed1762b5815b007e5dcc942a2e0e4))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([d11f1ff](https://github.com/brapi-dev/brapi-python/commit/d11f1ffe7fe451a81c01c4cc90054f6e4190e2de))
* **internal:** grammar fix (it's -&gt; its) ([1d324d4](https://github.com/brapi-dev/brapi-python/commit/1d324d4f8e18fde597d35938226fd2ca7efda9d1))
* **package:** drop Python 3.8 support ([0d274f6](https://github.com/brapi-dev/brapi-python/commit/0d274f6b323c4005e8e5ad10fac72c3aca27e3b8))

## 1.0.1 (2025-10-18)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/brapi-dev/brapi-python/compare/v1.0.0...v1.0.1)

### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([58fd5fc](https://github.com/brapi-dev/brapi-python/commit/58fd5fc95c4b0b4e3f92fc5bca2d6dcea5bbe8c9))

## 1.0.0 (2025-10-12)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/brapi-dev/brapi-python/compare/v0.0.1...v1.0.0)

### Chores

* sync repo ([a54d73b](https://github.com/brapi-dev/brapi-python/commit/a54d73b6e3d9e6f0347ff61d73885cf6cadb4c56))
* update SDK settings ([5313c1b](https://github.com/brapi-dev/brapi-python/commit/5313c1bccd7d4366b768ec14fa6a22cb0ebbefd0))
* update SDK settings ([604a534](https://github.com/brapi-dev/brapi-python/commit/604a534b7fc3daf6e9128a98e74aca9295a02c70))
* update SDK settings ([551afe3](https://github.com/brapi-dev/brapi-python/commit/551afe39d139c11f6e6ace580ed8faa06217a073))
* update SDK settings ([14efeb5](https://github.com/brapi-dev/brapi-python/commit/14efeb558642ad68760ce354f10d6f37a1df7f68))
